@@ -16,5 +16,8 @@ pub use self::cubes::{Cube, Cubes};
 mod auth;
 pub use self::auth::{ITokenProvider, DefaultTokenProvider};
 
+mod account;
+pub use self::account::{AuthenticatedTokenProvider, AccountInfo};
+
 /// Token defined in a javascript file from Freejam which never expires
 pub const DEFAULT_TOKEN: &str = "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJQdWJsaWNJZCI6IjEyMyIsIkRpc3BsYXlOYW1lIjoiVGVzdCIsIlJvYm9jcmFmdE5hbWUiOiJGYWtlQ1JGVXNlciIsIkZsYWdzIjpbXSwiaXNzIjoiRnJlZWphbSIsInN1YiI6IldlYiIsImlhdCI6MTU0NTIyMzczMiwiZXhwIjoyNTQ1MjIzNzkyfQ.ralLmxdMK9rVKPZxGng8luRIdbTflJ4YMJcd25dKlqg";
