@@ -1,4 +1,6 @@
-use crate::techblox::{SerializedEntityDescriptor, Parsable, SerializedEntityComponent, blocks::BlockEntity};
+use std::convert::AsRef;
+
+use crate::techblox::{SerializedEntityDescriptor, Parsable, SerializedEntityComponent, blocks::{BlockEntity, Block}};
 use libfj_parsable_macro_derive::*;
 
 /// Pilot seat entity descriptor (V4)
@@ -32,6 +34,14 @@ impl SerializedEntityDescriptor for PilotSeatEntity {
     }
 }
 
+impl AsRef<BlockEntity> for PilotSeatEntity {
+    fn as_ref(&self) -> &BlockEntity {
+        &self.block
+    }
+}
+
+impl Block for PilotSeatEntity {}
+
 /// Seat settings entity component.
 #[derive(Copy, Clone, Parsable)]
 pub struct SeatFollowCamComponent {
